@@ -52,10 +52,13 @@ class EnedisAnalytics:
             # because Pandas considers midnight as the next day while
             # for Enedis it is the day before
             if "interval_length" in self.df:
-                self.df.date = self.df.date.transform(self._midnightminus)
+                self.df.date = self.df.date.transform(self._minuteminus)
 
             if start_date:
-                self.df = self.df[(self.df.date > f"{start_date} 23:59:59")]
+                dt_start_date = pd.to_datetime(start_date, format="%Y-%m-%d %H:%M:%S")
+                dt_start_date = dt_start_date.tz_localize(self.local_timezone)
+                dt_start_date = self._midnightminus(dt_start_date)
+                self.df = self.df[(self.df.date > dt_start_date)]
 
             self.df.index = self.df.date
 
@@ -134,6 +137,15 @@ class EnedisAnalytics:
             dt_date = dt_date - timedelta(minutes=1)
         return dt_date
 
+    def _minuteminus(self, dt_date: dt) -> dt:
+        """Subtracts one minute.
+
+        to avoid taking midnight on the next day
+        """
+        if dt_date.minute == dt.strptime("00:00:00", "%H:%M:%S").minute:
+            dt_date = dt_date - timedelta(minutes=1)
+        return dt_date
+
     def _get_data_interval(self, intervalls: list[Tuple[str, str]]) -> pd.DataFrame:
         """Group date from range time."""
         for intervall in intervalls:
